@@ -567,7 +567,7 @@ rsvg_node_image_set_atts (RsvgNode *self, RsvgHandle *ctx, RsvgPropertyBag *atts
 			if ((value = rsvg_property_bag_lookup (atts, "id")))
 				{
 					id = value;
-					rsvg_defs_register_name (ctx->defs, id, &image->super);
+					rsvg_defs_register_name (ctx->priv->defs, id, &image->super);
 				}
 			if ((value = rsvg_property_bag_lookup (atts, "preserveAspectRatio")))
 				image->preserve_aspect_ratio = rsvg_css_parse_aspect_ratio (value);
